@@ -1,8 +1,13 @@
-from collections import namedtuple
+"""
+Modified from https://github.com/pytorch/vision/blob/main/torchvision/models/inception.py
+"""
 import warnings
+from collections import namedtuple
+from typing import Callable, Any, Optional, Tuple, List
+
 import oneflow as flow
 from oneflow import nn, Tensor
-from typing import Callable, Any, Optional, Tuple, List
+
 from .utils import load_state_dict_from_url
 from .registry import ModelCreator
 
@@ -11,7 +16,7 @@ __all__ = ["Inception3", "inception_v3", "InceptionOutputs", "_InceptionOutputs"
 
 
 model_urls = {
-    "inception_v3": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/Inception/inception_v3.zip",
+    "inception_v3": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/Inception/inception_v3.zip",
 }
 
 InceptionOutputs = namedtuple("InceptionOutputs", ["logits", "aux_logits"])
@@ -24,19 +29,29 @@ _InceptionOutputs = InceptionOutputs
 
 @ModelCreator.register_model
 def inception_v3(pretrained: bool = False, progress: bool = True, **kwargs: Any):
-    r"""Inception v3 model architecture from
-    `"Rethinking the Inception Architecture for Computer Vision" <http://arxiv.org/abs/1512.00567>`_.
-    The required minimum input size of the model is 75x75.
+    """
+    Constructs Inception v3 model.
+
     .. note::
-        **Important**: In contrast to the other models the inception_v3 expects tensors with a size of
+        Inception v3 model from the `Rethinking the Inception Architecture for Computer Vision <http://arxiv.org/abs/1512.00567>`_ paper.
+        In contrast to the other models the inception_v3 expects tensors with a size of
         N x 3 x 299 x 299, so ensure your images are sized accordingly.
+
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
         aux_logits (bool): If True, add an auxiliary branch that can improve training.
             Default: *True*
         transform_input (bool): If True, preprocesses the input according to the method with which it
             was trained on ImageNet. Default: *False*
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> inception_v3 = flowvision.models.inception_v3(pretrained=False, progress=True)
+
     """
     if pretrained:
         if "transform_input" not in kwargs:
@@ -80,14 +95,10 @@ class Inception3(nn.Module):
                 InceptionE,
                 InceptionAux,
             ]
+
         if init_weights is None:
-            warnings.warn(
-                "The default weight initialization of inception_v3 will be changed in future releases of "
-                "torchvision. If you wish to keep the old behavior (which leads to long initialization times"
-                " due to scipy/scipy#11299), please set init_weights=True.",
-                FutureWarning,
-            )
             init_weights = True
+
         assert len(inception_blocks) == 7
         conv_block = inception_blocks[0]
         inception_a = inception_blocks[1]
