@@ -1,9 +1,14 @@
+"""
+Modified from https://github.com/pytorch/vision/blob/main/torchvision/models/resnet.py
+"""
+from typing import Type, Any, Callable, Union, List, Optional
+
 import oneflow as flow
 import oneflow.nn as nn
 from oneflow import Tensor
-from .utils import load_state_dict_from_url
+
 from .registry import ModelCreator
-from typing import Type, Any, Callable, Union, List, Optional
+from .utils import load_state_dict_from_url
 
 __all__ = [
     "ResNet",
@@ -20,15 +25,15 @@ __all__ = [
 
 
 model_urls = {
-    "resnet18": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/ResNet/resnet18.zip",
-    "resnet34": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/ResNet/resnet34.zip",
-    "resnet50": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/ResNet/resnet50.zip",
-    "resnet101": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/ResNet/resnet101.zip",
-    "resnet152": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/ResNet/resnet152.zip",
-    "resnext50_32x4d": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/ResNet/resnext50_32x4d.zip",
-    "resnext101_32x8d": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/ResNet/resnext101_32x8d.zip",
-    "wide_resnet50_2": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/ResNet/wide_resnet50_2.zip",
-    "wide_resnet101_2": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/ResNet/wide_resnet101_2.zip",
+    "resnet18": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/ResNet/resnet18.zip",
+    "resnet34": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/ResNet/resnet34.zip",
+    "resnet50": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/ResNet/resnet50.zip",
+    "resnet101": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/ResNet/resnet101.zip",
+    "resnet152": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/ResNet/resnet152.zip",
+    "resnext50_32x4d": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/ResNet/resnext50_32x4d.zip",
+    "resnext101_32x8d": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/ResNet/resnext101_32x8d.zip",
+    "wide_resnet50_2": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/ResNet/wide_resnet50_2.zip",
+    "wide_resnet101_2": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/ResNet/wide_resnet101_2.zip",
 }
 
 
@@ -306,48 +311,92 @@ def _resnet(
 
 @ModelCreator.register_model
 def resnet18(pretrained: bool = False, progress: bool = True, **kwargs: Any) -> ResNet:
-    r"""ResNet-18 model from
-    `"Deep Residual Learning for Image Recognition" <https://arxiv.org/pdf/1512.03385.pdf>`_.
+    """
+    Constructs the ResNet-18 model.
+
+    .. note::
+        `Deep Residual Learning for Image Recognition <https://arxiv.org/pdf/1512.03385.pdf>`_.
 
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> resnet18 = flowvision.models.resnet18(pretrained=False, progress=True)
+
     """
     return _resnet("resnet18", BasicBlock, [2, 2, 2, 2], pretrained, progress, **kwargs)
 
 
 @ModelCreator.register_model
 def resnet34(pretrained: bool = False, progress: bool = True, **kwargs: Any) -> ResNet:
-    r"""ResNet-34 model from
-    `"Deep Residual Learning for Image Recognition" <https://arxiv.org/pdf/1512.03385.pdf>`_.
+    """
+    Constructs the ResNet-34 model.
+
+    .. note::
+        `Deep Residual Learning for Image Recognition <https://arxiv.org/pdf/1512.03385.pdf>`_.
 
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> resnet34 = flowvision.models.resnet34(pretrained=False, progress=True)
+
     """
     return _resnet("resnet34", BasicBlock, [3, 4, 6, 3], pretrained, progress, **kwargs)
 
 
 @ModelCreator.register_model
 def resnet50(pretrained: bool = False, progress: bool = True, **kwargs: Any) -> ResNet:
-    r"""ResNet-50 model from
-    `"Deep Residual Learning for Image Recognition" <https://arxiv.org/pdf/1512.03385.pdf>`_.
+    """
+    Constructs the ResNet-50 model.
+
+    .. note::
+        `Deep Residual Learning for Image Recognition <https://arxiv.org/pdf/1512.03385.pdf>`_.
 
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> resnet50 = flowvision.models.resnet50(pretrained=False, progress=True)
+
     """
     return _resnet("resnet50", Bottleneck, [3, 4, 6, 3], pretrained, progress, **kwargs)
 
 
 @ModelCreator.register_model
 def resnet101(pretrained: bool = False, progress: bool = True, **kwargs: Any) -> ResNet:
-    r"""ResNet-101 model from
-    `"Deep Residual Learning for Image Recognition" <https://arxiv.org/pdf/1512.03385.pdf>`_.
+    """
+    Constructs the ResNet-101 model.
+
+    .. note::
+        `Deep Residual Learning for Image Recognition <https://arxiv.org/pdf/1512.03385.pdf>`_.
 
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> resnet101 = flowvision.models.resnet101(pretrained=False, progress=True)
+
     """
     return _resnet(
         "resnet101", Bottleneck, [3, 4, 23, 3], pretrained, progress, **kwargs
@@ -356,12 +405,23 @@ def resnet101(pretrained: bool = False, progress: bool = True, **kwargs: Any) ->
 
 @ModelCreator.register_model
 def resnet152(pretrained: bool = False, progress: bool = True, **kwargs: Any) -> ResNet:
-    r"""ResNet-152 model from
-    `"Deep Residual Learning for Image Recognition" <https://arxiv.org/pdf/1512.03385.pdf>`_.
+    """
+    Constructs the ResNet-152 model.
+
+    .. note::
+        `Deep Residual Learning for Image Recognition <https://arxiv.org/pdf/1512.03385.pdf>`_.
 
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> resnet152 = flowvision.models.resnet152(pretrained=False, progress=True)
+
     """
     return _resnet(
         "resnet152", Bottleneck, [3, 8, 36, 3], pretrained, progress, **kwargs
@@ -372,12 +432,23 @@ def resnet152(pretrained: bool = False, progress: bool = True, **kwargs: Any) ->
 def resnext50_32x4d(
     pretrained: bool = False, progress: bool = True, **kwargs: Any
 ) -> ResNet:
-    r"""ResNeXt-50 32x4d model from
-    `"Aggregated Residual Transformation for Deep Neural Networks" <https://arxiv.org/pdf/1611.05431.pdf>`_.
+    """
+    Constructs the ResNeXt-50 32x4d model.
+
+    .. note::
+        `Aggregated Residual Transformation for Deep Neural Networks <https://arxiv.org/pdf/1611.05431.pdf>`_.
 
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> resnext50_32x4d = flowvision.models.resnext50_32x4d(pretrained=False, progress=True)
+
     """
     kwargs["groups"] = 32
     kwargs["width_per_group"] = 4
@@ -390,12 +461,23 @@ def resnext50_32x4d(
 def resnext101_32x8d(
     pretrained: bool = False, progress: bool = True, **kwargs: Any
 ) -> ResNet:
-    r"""ResNeXt-101 32x8d model from
-    `"Aggregated Residual Transformation for Deep Neural Networks" <https://arxiv.org/pdf/1611.05431.pdf>`_.
+    """
+    Constructs the ResNeXt-101 32x8d model.
+
+    .. note::
+        `Aggregated Residual Transformation for Deep Neural Networks <https://arxiv.org/pdf/1611.05431.pdf>`_.
 
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> resnext101_32x8d = flowvision.models.resnext101_32x8d(pretrained=False, progress=True)
+
     """
     kwargs["groups"] = 32
     kwargs["width_per_group"] = 8
@@ -408,17 +490,27 @@ def resnext101_32x8d(
 def wide_resnet50_2(
     pretrained: bool = False, progress: bool = True, **kwargs: Any
 ) -> ResNet:
-    r"""Wide ResNet-50-2 model from
-    `"Wide Residual Networks" <https://arxiv.org/pdf/1605.07146.pdf>`_.
+    """
+    Constructs the Wide ResNet-50-2 model.
 
-    The model is the same as ResNet except for the bottleneck number of channels
-    which is twice larger in every block. The number of channels in outer 1x1
-    convolutions is the same, e.g. last block in ResNet-50 has 2048-512-2048
-    channels, and in Wide ResNet-50-2 has 2048-1024-2048.
+    .. note::
+        `Wide Residual Networks <https://arxiv.org/pdf/1605.07146.pdf>`_.
+        The model is the same as ResNet except for the bottleneck number of channels
+        which is twice larger in every block. The number of channels in outer 1x1
+        convolutions is the same, e.g. last block in ResNet-50 has 2048-512-2048
+        channels, and in Wide ResNet-50-2 has 2048-1024-2048.
 
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> wide_resnet50_2 = flowvision.models.wide_resnet50_2(pretrained=False, progress=True)
+
     """
     kwargs["width_per_group"] = 64 * 2
     return _resnet(
@@ -430,17 +522,26 @@ def wide_resnet50_2(
 def wide_resnet101_2(
     pretrained: bool = False, progress: bool = True, **kwargs: Any
 ) -> ResNet:
-    r"""Wide ResNet-101-2 model from
-    `"Wide Residual Networks" <https://arxiv.org/pdf/1605.07146.pdf>`_.
+    """
+    Constructs the Wide ResNet-101-2 model.
 
-    The model is the same as ResNet except for the bottleneck number of channels
-    which is twice larger in every block. The number of channels in outer 1x1
-    convolutions is the same, e.g. last block in ResNet-50 has 2048-512-2048
-    channels, and in Wide ResNet-50-2 has 2048-1024-2048.
+    .. note::
+        `Wide Residual Networks <https://arxiv.org/pdf/1605.07146.pdf>`_.
+        The model is the same as ResNet except for the bottleneck number of channels
+        which is twice larger in every block. The number of channels in outer 1x1
+        convolutions is the same, e.g. 
 
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> wide_resnet101_2 = flowvision.models.wide_resnet101_2(pretrained=False, progress=True)
+
     """
     kwargs["width_per_group"] = 64 * 2
     return _resnet(
